@@ -6,7 +6,7 @@ use utf8;
 use Carp;
 ## no critic (RequireCarping)
 
-our $VERSION = 'v0.2.3';
+our $VERSION = 'v0.2.4';
 
 use List::Util qw( first );
 use File::Temp qw( tempfile ); # don't use Path::Tiny to have temp files in error $SHELL
@@ -449,7 +449,7 @@ App::migrate - upgrade / downgrade project
 
 =head1 VERSION
 
-This document describes App::migrate version v0.2.3
+This document describes App::migrate version v0.2.4
 
 
 =head1 SYNOPSIS
@@ -497,7 +497,7 @@ including installed packages, etc. - anything what has versions and need
 complex operations to upgrade/downgrade between these versions.
 For example, to migrate source code you can use VCS like Git or Mercurial,
 but they didn't support empty directories, file permissions (except
-executable), non-plain file types (fifo, UNIX socket, etc.), xattr, ACL,
+executable), non-plain file types (FIFO, UNIX socket, etc.), xattr, ACL,
 configuration files which must differ on each site, and databases. So, if
 you need to migrate anything isn't supported by VCS - you can try this
 module/tool.
@@ -533,15 +533,13 @@ backups while migration.
 
 =head1 INTERFACE
 
-=over
-
-=item new
+=head2 new
 
     $migrate = App::migrate->new;
 
 Create and return new App::migrate object.
 
-=item load
+=head2 load
 
     $migrate->load('path/to/migrate');
 
@@ -558,7 +556,7 @@ version values.
 Will throw if given file's contents don't conform to L</"Specification"> -
 this may be used to check file's syntax.
 
-=item find_paths
+=head2 find_paths
 
     @paths = $migrate->find_paths($from_version => $to_version);
 
@@ -606,7 +604,7 @@ this list with two paths (in any order):
         ['1.0.42', '1.2.0', …, '1.2.3', '1.2.4', '1.2.5'],
     )
 
-=item get_steps
+=head2 get_steps
 
     @steps = $migrate->get_steps( \@versions );
 
@@ -635,7 +633,7 @@ Each element in C<@steps> is a HASHREF with these keys:
 
 Will throw if unable to return requested steps.
 
-=item on
+=head2 on
 
     $migrate = $migrate->on(BACKUP  => \&your_handler);
     $migrate = $migrate->on(RESTORE => \&your_handler);
@@ -699,7 +697,7 @@ version-before-migration from backup).
 
 =back
 
-=item run
+=head2 run
 
     $migrate->run( \@versions );
 
@@ -710,8 +708,6 @@ Before executing each step will set C<$ENV{MIGRATE_PREV_VERSION}> to
 current version (which it will migrate from) and
 C<$ENV{MIGRATE_NEXT_VERSION}> to version it is trying to migrate to.
 
-=back
-
 
 =head1 SYNTAX
 
@@ -853,11 +849,20 @@ you'll have to use line with two spaces instead.
 
 =back
 
-Supported operations:
+While executing any commands two environment variables will be set:
+C<$MIGRATE_PREV_VERSION> and C<$MIGRATE_NEXT_VERSION> (first is always
+version we're migrating from, and second is always version we're migrating
+to - i.e. while downgrading C<$MIGRATE_NEXT_VERSION> will be lower/older
+version than C<$MIGRATE_PREV_VERSION>)
 
-=over
+All executed commands must complete without error, otherwise emergency
+shell will be started and user should either fix the error and C<exit>
+from shell to continue migration, or C<exit 1> from shell to interrupt
+migration and restore previous-before-this-migration version from backup.
 
-=item VERSION
+=head2 Supported operations
+
+=head3 VERSION
 
 Must have exactly one param (version number). Some symbols are not allowed
 in version numbers: special (0x00-0x1F,0x7F), both slash, all three
@@ -873,13 +878,13 @@ Each file must contain 'VERSION' operation before any migrate operations
 
 All operations after last 'VERSION' operation will be ignored.
 
-=item before_upgrade
+=head3 before_upgrade
 
-=item upgrade
+=head3 upgrade
 
-=item downgrade
+=head3 downgrade
 
-=item after_downgrade
+=head3 after_downgrade
 
 These operations must be always used in pairs: first must be one of
 'before_upgrade' or 'upgrade' operation, second must be one of 'downgrade'
@@ -934,7 +939,7 @@ C<#!>), which will be made executable and run without any params.
 
 =back
 
-=item RESTORE
+=head3 RESTORE
 
 Doesn't support any params, neither usual nor multiline.
 
@@ -945,7 +950,7 @@ operations then all 'downgrade' and 'after_downgrade' operations between
 same 'VERSION' operations will be ignored and on downgrading previous
 version will be restored from backup.
 
-=item DEFINE
+=head3 DEFINE
 
 This operation must have only one non-multiline param - name of defined
 macro. This name must not be same as one of existing operation names, both
@@ -983,7 +988,7 @@ params.
 
 =back
 
-=item DEFINE2
+=head3 DEFINE2
 
 Work similar to DEFINE, but require two next operations after it: first
 must be one of 'before_upgrade' or 'upgrade', and second must be one of
@@ -992,7 +997,7 @@ must be one of 'before_upgrade' or 'upgrade', and second must be one of
 Params of both operations will be combined with params of substituted
 operation as explained above.
 
-=item DEFINE4
+=head3 DEFINE4
 
 Work similar to DEFINE, but require four next operations after it: first
 must be 'before_upgrade', second - 'upgrade', third - 'downgrade', fourth
@@ -1001,19 +1006,6 @@ must be 'before_upgrade', second - 'upgrade', third - 'downgrade', fourth
 Params of all four operations will be combined with params of substituted
 operation as explained above.
 
-=back
-
-While executing any commands two environment variables will be set:
-C<$MIGRATE_PREV_VERSION> and C<$MIGRATE_NEXT_VERSION> (first is always
-version we're migrating from, and second is always version we're migrating
-to - i.e. while downgrading C<$MIGRATE_NEXT_VERSION> will be lower/older
-version than C<$MIGRATE_PREV_VERSION>)
-
-All executed commands must complete without error, otherwise emergency
-shell will be started and user should either fix the error and C<exit>
-from shell to continue migration, or C<exit 1> from shell to interrupt
-migration and restore previous-before-this-migration version from backup.
-
 
 =head1 SUPPORT
 
@@ -1067,11 +1059,11 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2015- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
   The MIT (X11) License
 
 
-=cut
\ No newline at end of file
+=cut
